:orphan:

.. _Magic Variables, and How To Access Information About Other Hosts: https://docs.ansible.com/ansible/latest/user_guide/playbooks_variables.html#accessing-information-about-other-hosts-with-magic-variables
.. _FDEunlock: https://gitlab.com/ypid/fdeunlock
